Attachment class sealed

An abstract class representing an attachment in a chat message.

This class serves as a base for different types of attachments (e.g., files, images, links) that can be included in a chat message.

Implementers
Annotations

Properties

hashCode int
The hash code for this object.
no setterinherited
isImage bool
Whether this attachment holds displayable image content.
no setter
name String
The name of the attachment.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited