LlmCancelException class

Exception thrown when an LLM operation is cancelled.

This exception is used to indicate that an LLM operation was intentionally cancelled, typically by user action or a timeout.

Inheritance
Annotations

Constructors

LlmCancelException()
Creates a new LlmCancelException.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The message describing the error that occurred.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited