LlmException class abstract

Exception class for LLM-related errors.

This class is used to represent exceptions that occur during LLM (Language Learning Model) operations.

Implemented types
Implementers
Annotations

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The message describing the error that occurred.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited