LlmFailureException class

Exception thrown when an LLM operation fails.

This exception is used to represent failures in LLM operations that are not due to cancellation, such as network errors or invalid responses from the LLM provider.

Inheritance
Annotations

Constructors

LlmFailureException([String message = ''])
Creates a new LlmFailureException with the given error message.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The message describing the error that occurred.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited