isLlm property
bool
get
isLlm
Checks if the message origin is from the LLM.
Implementation
bool get isLlm => this == MessageOrigin.llm;
Checks if the message origin is from the LLM.
bool get isLlm => this == MessageOrigin.llm;