ToolApprovalDecision enum

The user's decision for a pending ToolApprovalRequest.

Inheritance
Available extensions

Values

deny → const ToolApprovalDecision

Reject this call; the agent is told the user denied it.

allowOnce → const ToolApprovalDecision

Approve this call only.

alwaysAllow → const ToolApprovalDecision

Approve this call and record a standing rule that auto-approves all future calls to the same tool.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ToolApprovalDecision>
A constant List of the values in this enum, in order of their declaration.