beginRun property
Opens a run record for a turn about to start.
Supplied by the owner because only it knows the agent, model, and source labels to snapshot.
Implementation
final Future<AgentRunHandle> Function(AgentRunTelemetryStore runs)? beginRun;
Opens a run record for a turn about to start.
Supplied by the owner because only it knows the agent, model, and source labels to snapshot.
final Future<AgentRunHandle> Function(AgentRunTelemetryStore runs)? beginRun;