EchoLlmProvider class
A simple LLM provider that echoes the input prompt and attachment information.
This provider is primarily used for testing and debugging purposes.
- Inheritance
-
- Object
- LlmProvider
- EchoLlmProvider
- Mixed-in types
Constructors
-
EchoLlmProvider({Iterable<
ChatMessage> ? history}) - Creates an EchoLlmProvider instance with an optional chat history.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
-
history
↔ Iterable<
ChatMessage> -
Returns an iterable of
ChatMessageobjects representing the chat history.getter/setter pairoverride - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
inherited
-
generateStream(
String prompt, {Iterable< Attachment> attachments = const []}) → Stream<String> -
Generates a stream of text based on the given prompt and attachments.
This method does not interact with a chat or build on any chat history.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
sendMessageStream(
String prompt, {Iterable< Attachment> attachments = const []}) → Stream<String> -
Generates a stream of text based on the given prompt and attachments.
Interacts with a chat and builds on the history of the chat associated
with the provider.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited