LlmCancelException class
Exception thrown when an LLM operation is cancelled.
This exception is used to indicate that an LLM operation was intentionally cancelled, typically by user action or a timeout.
- Inheritance
-
- Object
- LlmException
- LlmCancelException
- Annotations
Constructors
- LlmCancelException()
-
Creates a new LlmCancelException.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited