LlmException class abstract
Exception class for LLM-related errors.
This class is used to represent exceptions that occur during LLM (Language Learning Model) operations.
- Implemented types
- Implementers
- Annotations
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited